[**Opciones avanzadas**](./introduction.md) > **Código de idioma** _(actual)_

---

#### Google

Fuente <https://developers.google.com/admin-sdk/directory/v1/languages?hl=zh-cn>, organizado por GPT-4o.

| Etiqueta en español | Etiqueta | `Código de idioma` |
| --- | --- | --- |
| Amárico | Amharic | `am` |
| Árabe | Arabic | `ar` |
| Euskara | Basque | `eu` |
| Bengalí | Bengali | `bn` |
| Inglés (Reino Unido) | English (UK) | `en-GB` |
| Portugués (Brasil) | Portuguese (Brazil) | `pt-BR` |
| Búlgaro | Bulgarian | `bg` |
| Catalán | Catalan | `ca` |
| Cherokee | Cherokee | `chr` |
| Croata | Croatian | `hr` |
| Checo | `cs` |
| Danés | Danish | `da` |
| Holandés | Dutch | `nl` |
| Inglés (EE. UU.) | English (US) | `en` |
| Estonio | Estonian | `et` |
| Filipino | `fil` |
| Finlandés | Finnish | `fi` |
| Español | Spanish | `es` |
| Español | Spanish | `es` |
| Griego | `el` |
| Gujarati | Gujarati | `gu` |
| Hebreo | Hebrew | `iw` |
| Hindi | Hindi | `hi` |
| Húngaro | Hungarian | `hu` |
| Islandés | Icelandic | `is` |
| Indonesio | Indonesian | `id` |
| Italiano | Italian | `it` |
| Japonés | Japanese | `ja` |
| Kannada | Kannada | `kn` |
| Coreano | `ko` |
| Letón | Latvian | `lv` |
| Lituano | Lithuanian | `lt` |
| Malayo | Malay | `ms` |
| Malayalam | Malayalam | `ml` |
| Marathi | `mr` |
| Noruego | `no` |
| Polaco | Polish | `pl` |
| Portugués (Portugal) | Portuguese (Portugal) | `pt-PT` |
| Rumano | Romanian | `ro` |
| Ruso | Russian | `ru` |
| 塞尔维亚语 | Serbian | `sr` |
| Español (España) | Spanish (Spain) | `es-ES` |
| Eslovaco | Slovak | `sk` |
| Esloveno | Slovenian | `sl` |
| Español | Spanish | `es` |
| Suajili | Swahili | `sw` |
| Español | Swedish | `sv` |
| Tamil | Tamil | `ta` |
| Telugu | Telugu | `te` |
| Tailandés | Thai | `th` |
| Chino (Taiwán) | Chinese (Taiwan) | `zh-TW` |
| Turco | `tr` |
| Urdu | Urdu | `ur` |
| Ucraniano | Ukrainian | `uk` |
| Vietnamita | Vietnamese | `vi` |
| Galés | Welsh | `cy` |

#### DeepL

Fuente <https://developers.deepl.com/docs/resources/supported-languages>, organizado por GPT-4o.

| Etiqueta en español | Etiqueta | `Language Code` | Soporta |
| --- | --- | --- | --- |
| Árabe | Arabic | `AR` | `source`, `target` |
| Búlgaro | Bulgarian | `BG` | `source`, `target` |
| Checo | Czech | `CS` | `source`, `target` |
| Danés | Danish | `DA` | `source`, `target` |
| Alemán | German | `DE` | `source`, `target` |
| Griego | Greek | `EL` | `source`, `target` |
| Español | `ES` | `source`, `target` |
|------|---------|------|--------------------|--------|----------|------|--------------------|
| 中文 | Chinese | `ZH` | `source`, `target` | Francés | French   | `FR` | `source`, `target` |
| 德语 | German  | `DE` | `source`, `target` | Italiano | Italian  | `IT` | `source`, `target` |
| 日语 | Japanese| `JA` | `source`, `target` | Coreano | Korean   | `KO` | `source`, `target` |
| 俄语 | Russian | `RU` | `source`, `target` | Portugués | Portuguese| `PT` | `source`, `target` |
| Español (España) | Spanish (Spanish) | `ES-ES` | `target` |
| Español (Estados Unidos) | English (American) | `EN-US` | `target` |
| Español | Spanish | `ES` | `source`, `target` |
| Estonio | Estonian | `ET` | `source`, `target` |
| Finés | Finnish | `FI` | `source`, `target` |
| Francés | French | `FR` | `source`, `target` |
| Húngaro | Hungarian | `HU` | `source`, `target` |
| Indonesio | Indonesian | `ID` | `source`, `target` |
| Italiano | Italian | `IT` | `source`, `target` |
| Japonés | Japanese | `JA` | `source`, `target` |
| Coreano | Korean | `KO` | `source`, `target` |
| Lituano | Lithuanian | `LT` | `source`, `target` |
| Letón | Latvian | `LV` | `source`, `target` |
| Bokmål noruego | Norwegian Bokmål | `NB` | `source`, `target` |
| Neerlandés | Dutch | `NL` | `source`, `target` |
| Polaco | Polish | `PL` | `source`, `target` |
| Portugués | Portuguese | `PT` | `source`, `target` |
|  Portugués (Brasileño) | Portuguese (Brazilian) | `PT-BR` | `target` |
| Português (Europeu) | Portuguese (European) | `PT-PT` | `target` |
| Rumano | Romanian | `RO` | `source`, `target` |
| Ruso | Russian | `RU` | `source`, `target` |
| Eslovaco | Slovak | `SK` | `source`, `target` |
| Esloveno | Slovenian | `SL` | `source`, `target` |
| Sueco | Swedish | `SV` | `source`, `target` |
| Turco | Turkish | `TR` | `source`, `target` |
| Ucraniano | Ukrainian | `UK` | `source`, `target` |
| 中文 | Chino | `ZH` | `source`, `target` |
| Español | Spanish | `ES` | `target` |
| 中文（繁体） | Chino (Tradicional) | `ZH-HANT` | `target` |

<div align="right"> 
<h6><small>Parte del contenido de esta página ha sido traducido por GPT y puede contener errores.</small></h6>